DiGraph

Struct DiGraph 

pub struct DiGraph<N>
where N: GraphNode,
{ /* private fields */ }
A directed graph using reference-counted nodes.

Implementations

Source

impl<N> DiGraph<N>
where N: GraphNode,

pub fn new(nodes: IndexSet<N>) -> DiGraph<N>

Initializes a new DiGraph from a set of source nodes.

pub fn add_node(&mut self, node: N)

Adds a node to the graph.

pub fn nodes(&self) -> impl Iterator<Item = &N>

Returns an iterator over the nodes in the graph.

pub fn add_edge(&mut self, from: N, to: N)

Adds an edge to the graph.

pub fn remove_node(&mut self, node: &N) -> bool

Removes a node and all associated edges from the graph.

pub fn neighbors(&self, node: &N) -> impl Iterator<Item = &N>

Returns an iterator to the immediate neighbors of a given node.

pub fn transitive_closure(&self, node: &N) -> IndexSet<N>

Returns all the nodes that can be reached by a given node

pub fn contains_node(&self, node: N) -> bool

Returns true if the graph contains the given node.

pub fn post_order(&self) -> Result<IndexSet<N>, DiGraphError<N>>

Returns the post-order ordering of the graph. Detects if there is a cycle in the graph.

pub fn post_order_with_filter<F>( &self, filter: F, ) -> Result<IndexSet<N>, DiGraphError<N>>
where F: Fn(&N) -> bool,

Returns the post-order ordering of the graph but only considering a subset of the nodes that satisfy the given filter.

Detects if there is a cycle in the graph.

pub fn retain_nodes(&mut self, keep: &IndexSet<N>)

Retains a subset of the nodes, and removes all edges in which the source or destination is not in the subset.