pub struct Program {
pub modules: IndexMap<Vec<Symbol>, Module>,
pub imports: IndexMap<Symbol, ProgramId>,
pub stubs: IndexMap<Symbol, Stub>,
pub program_scopes: IndexMap<Symbol, ProgramScope>,
}Expand description
Stores the Leo program abstract syntax tree.
Fields
modules: IndexMap<Vec<Symbol>, Module>A map from module paths to module definitions.
imports: IndexMap<Symbol, ProgramId>A map from import names (including the .aleo if present) to import definitions.
stubs: IndexMap<Symbol, Stub>A map from program stub names to program stub scopes.
program_scopes: IndexMap<Symbol, ProgramScope>A map from program names to program scopes.
Implementations
Sourceimpl Program
impl Program
Sourcepub fn to_json_string(&self) -> Result<String, LeoError>
pub fn to_json_string(&self) -> Result<String, LeoError>
Serializes the ast into a JSON string.
pub fn to_json_value(&self) -> Result<Value, LeoError>
Sourcepub fn to_json_file(
&self,
path: PathBuf,
file_name: &str,
) -> Result<(), LeoError>
pub fn to_json_file( &self, path: PathBuf, file_name: &str, ) -> Result<(), LeoError>
Serializes the ast into a JSON file.
Sourcepub fn to_json_file_without_keys(
&self,
path: PathBuf,
file_name: &str,
excluded_keys: &[&str],
) -> Result<(), LeoError>
pub fn to_json_file_without_keys( &self, path: PathBuf, file_name: &str, excluded_keys: &[&str], ) -> Result<(), LeoError>
Serializes the ast into a JSON value and removes keys from object mappings before writing to a file.