leo-compiler
Modules
- run
- Utilities for running Leo programs in test environments.
Structs
- Bytecode
- Bytecode for a single program.
- Compiled
- The result of compiling a Leo program.
- Compiled
Program - A single compiled program with its bytecode and ABI.
- Compiled
Programs - The result of code generation for a Leo program.
- Compiler
- The primary entry point of the Leo compiler.
- Compiler
Options - DiGraph
- A directed graph using reference-counted nodes.
- Disk
File Source - Reads source files from the real filesystem.
- Frontend
Analysis - Borrowed frontend state after parsing and semantic frontend passes complete.
- InMemory
File Source - Reads source files from in-memory buffers.
- Loaded
Import Stubs - Import stubs together with the filesystem inputs that invalidate them.
- Program
- Stores the Leo program abstract syntax tree.
Enums
- Ast
- The abstract syntax tree (AST) for a Leo program.
- AstSnapshots
Traits
- File
Source - Abstraction over where the compiler reads source files from.
Functions
- load_
import_ stubs_ for_ package - Loads only locally resolvable dependency stubs for a package.
- load_
import_ stubs_ for_ package_ with_ file_ source - Load local dependency stubs using an explicit file source for Leo source reads.