Crate leo_compiler

Crate leo_compiler 

leo-compiler

Crates.io License

Modules

run
Utilities for running Leo programs in test environments.

Structs

Bytecode
Bytecode for a single program.
Compiled
The result of compiling a Leo program.
CompiledProgram
A single compiled program with its bytecode and ABI.
CompiledPrograms
The result of code generation for a Leo program.
Compiler
The primary entry point of the Leo compiler.
CompilerOptions
DiGraph
A directed graph using reference-counted nodes.
DiskFileSource
Reads source files from the real filesystem.
InMemoryFileSource
Reads source files from in-memory buffers.
Program
Stores the Leo program abstract syntax tree.

Enums

Ast
The abstract syntax tree (AST) for a Leo program.
AstSnapshots

Traits

FileSource
Abstraction over where the compiler reads source files from.