pub struct DiGraph<N>where
N: GraphNode,{ /* private fields */ }Expand description
A directed graph using reference-counted nodes.
Implementations
Sourceimpl<N> DiGraph<N>where
N: GraphNode,
impl<N> DiGraph<N>where
N: GraphNode,
Sourcepub fn new(nodes: IndexSet<N>) -> DiGraph<N>
pub fn new(nodes: IndexSet<N>) -> DiGraph<N>
Initializes a new DiGraph from a set of source nodes.
Sourcepub fn nodes(&self) -> impl Iterator<Item = &N>
pub fn nodes(&self) -> impl Iterator<Item = &N>
Returns an iterator over the nodes in the graph.
Sourcepub fn remove_node(&mut self, node: &N) -> bool
pub fn remove_node(&mut self, node: &N) -> bool
Removes a node and all associated edges from the graph.
Sourcepub fn neighbors(&self, node: &N) -> impl Iterator<Item = &N>
pub fn neighbors(&self, node: &N) -> impl Iterator<Item = &N>
Returns an iterator to the immediate neighbors of a given node.
Sourcepub fn transitive_closure(&self, node: &N) -> IndexSet<N>
pub fn transitive_closure(&self, node: &N) -> IndexSet<N>
Returns all the nodes that can be reached by a given node
Sourcepub fn contains_node(&self, node: N) -> bool
pub fn contains_node(&self, node: N) -> bool
Returns true if the graph contains the given node.
Sourcepub fn post_order(&self) -> Result<IndexSet<N>, DiGraphError<N>>
pub fn post_order(&self) -> Result<IndexSet<N>, DiGraphError<N>>
Returns the post-order ordering of the graph. Detects if there is a cycle in the graph.
Sourcepub fn post_order_with_filter<F>(
&self,
filter: F,
) -> Result<IndexSet<N>, DiGraphError<N>>
pub fn post_order_with_filter<F>( &self, filter: F, ) -> Result<IndexSet<N>, DiGraphError<N>>
Returns the post-order ordering of the graph but only considering a subset of the nodes that satisfy the given filter.
Detects if there is a cycle in the graph.
Sourcepub fn retain_nodes(&mut self, keep: &IndexSet<N>)
pub fn retain_nodes(&mut self, keep: &IndexSet<N>)
Retains a subset of the nodes, and removes all edges in which the source or destination is not in the subset.